invictus_api library
Classes
- ActivityManager
- ActivityManagerChannel
- AlarmManager
- AlarmManagerChannel
- AutoCloseable
- BitSet
- BitSetChannel
- Build
- Information about the current build, extracted from system properties.
- Build$Partition
- Build information for a particular device partition.
- Build$PartitionChannel
- Build$Version
- Various version strings.
- Build$VersionChannel
- Build$VersionCodes
- Enumeration of the currently known SDK version codes. These are the values that can be found in VERSION.SDK. Version numbers increment monotonically with each official platform release.
- Build$VersionCodesChannel
- Build$VersionCodesFull
- Enumeration of the currently known SDK major and minor version codes. The numbers increase for every release, and are guaranteed to be ordered by the release date of each release. The actual values should be considered an implementation detail, and the current encoding scheme may change in the future.
- Build$VersionCodesFullChannel
- BuildChannel
- Closeable
- ConnectivityManager
- ConnectivityManager$NetworkCallback
- ConnectivityManager$OnNetworkActiveListener
- ConnectivityManagerChannel
- DatagramSocket
- DhcpInfo
- DhcpInfoChannel
- EthernetManager
- EthernetManager$Listener
- EthernetManagerChannel
- ExternalTimeSuggestion
- ExternalTimeSuggestionChannel
- FileDescriptor
- Flushable
- Inet4Address
- Inet4AddressChannel
- Inet4AddressUtil
- Inet4AddressUtilChannel
- Inet6Address
- Inet6AddressChannel
- InetAddress
- InetAddressChannel
- InetAddresses
- InetAddressesChannel
- InetSocketAddress
- InputStream
- InterfaceAddress
- IpConfiguration
- IpConfigurationChannel
- IpPrefix
- IpSecManager$UdpEncapsulationSocket
- LinkAddress
- LinkAddressChannel
- LinkProperties
- Locale
- Locale$LanguageRange
- Locale$LanguageRangeChannel
- LocaleChannel
- LocaleList
- LocaleListChannel
- LocalePicker
- LocalePicker$LocaleInfo
- LocalePicker$LocaleSelectionListener
- LocalePickerChannel
- MacAddress
- MloLink
- Network
- NetworkCapabilities
- NetworkChannel
- NetworkInfo
- NetworkInfo$DetailedState
- NetworkInterface
- This class represents a Network Interface made up of a name, and a list of IP addresses assigned to this interface. It is used to identify the local interface on which a multicast group is joined. Interfaces are normally known by names such as "le0".
- NetworkInterfaceChannel
- NetworkRequest
- NetworkRequestChannel
- NetworkSpecifier
- NetworkUtil
- NetworkUtilChannel
- OutputStream
- ParcelFileDescriptor
- PowerManager
- This class lets you query and request control of aspects of the device's power state.
- PowerManagerChannel
- Proxy
- ProxyInfo
- RouteInfo
- Runnable
- RunnableChannel
- ScanResult
- ScanResult$InformationElement
- ScanResultChannel
- Settings
- Settings$Global
- Settings$GlobalChannel
- Settings$NameValueTable
- Settings$NameValueTableChannel
- Settings$Secure
- Settings$SecureChannel
- Settings$System
- Settings$SystemChannel
- SettingsChannel
- Socket
- SocketFactory
- SocketKeepalive
- SocketKeepalive$Callback
- StaticIpConfiguration
- StaticIpConfigurationChannel
- SupplicantStateChannel
- SystemClock
- Core timekeeping facilities.
- SystemClockChannel
- SystemProperties
- Gives access to the system properties store. The system properties store contains a list of string key-value pairs.
- SystemProperties$Handle
- Handle to a pre-located property. Looking up a property handle in advance allows for optimal repeated lookup of a single property.
- SystemPropertiesChannel
- TimeCapabilities
- TimeCapabilities$Builder
- TimeCapabilitiesAndConfig
- TimeCapabilitiesChannel
- TimeConfiguration
- TimeConfiguration$Builder
- TimeConfigurationChannel
- TimeManager
- TimeManager$TimeZoneDetectorListener
- TimeManagerChannel
- TimeState
- TimeZone
- represents a time zone offset, and also figures out daylight savings.
- TimeZoneCapabilities
- TimeZoneCapabilities$Builder
- TimeZoneCapabilitiesAndConfig
- TimeZoneCapabilitiesChannel
- TimeZoneChannel
- TimeZoneConfiguration
- TimeZoneConfiguration$Builder
- TimeZoneConfigurationChannel
- TimeZoneState
- TransportInfo
- ULocale
- UnixEpochTime
- UnixEpochTimeChannel
- Uri
- Url
- UrlConnection
- UsbAccessory
- UsbConfiguration
- UsbConstants
- UsbConstantsChannel
- UsbDevice
- UsbDeviceChannel
- UsbDeviceConnection
- UsbEndpoint
- UsbInterface
- UsbManager
- UsbManager$UsbAccessoryListener
- UsbManager$UsbDeviceListener
- UsbManagerChannel
- UsbRequest
- UsbRequestChannel
- WifiAwareNetworkInfo
- WifiConfiguration
- WifiConfiguration$KeyMgmt
- WifiConfiguration$KeyMgmtChannel
- WifiConfigurationChannel
- WifiEnterpriseConfig
- WifiInfo
- WifiInfoChannel
- WifiManager
- WifiManager$ScanResultsCallback
- WifiManager$WifiStateChangedListener
- WifiManagerChannel
- WifiSsid
- WifiSsidChannel
Enums
- Build$BackportedFixStatus
- Capabilities
- ConnectivityManager$RestrictBackgroundStatus
- ConnectivityManager$Type
- IpConfiguration$IpAssignment
- Locale$Category
- Enum for locale categories. These locale categories are used to get/set the default locale for the specific functionality represented by the category.
- Locale$FilteringMode
- This enum provides constants to select a filtering mode for locale matching. Refer to RFC 4647 Matching of Language Tags for details.
- Locale$IsoCountryCode
- Enum for specifying the type defined in ISO 3166. This enum is used to retrieve the two-letter ISO3166-1 alpha-2, three-letter ISO3166-1 alpha-3, four-letter ISO3166-3 country codes.
- NetworkCapabilities$NetCapability
- NetworkCapabilities$Transport
- PowerManager$Reboot
- PowerManager$Shutdown
- RouteInfo$RTN
- ScanResult$ChannelWidth
- ScanResult$Preamble
- ScanResult$WifiBand
- ScanResult$WifiStandard
- SupplicantState
- UsbDir
- UsbEndpointXfer
- WifiConfiguration$Status
- WifiInfo$SecurityType
- WifiManager$WifiState