Inet4Address class abstract interface

Implemented types

Constructors

Inet4Address()
factory

Properties

address Uint8List
no setterinherited
canonicalHostName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hostAddress String?
no setterinherited
hostName String
no setterinherited
isAnyLocalAddress bool
no setterinherited
isLinkLocalAddress bool
no setterinherited
isLoopbackAddress bool
no setterinherited
isMcGlobal bool
no setterinherited
isMcLinkLocal bool
no setterinherited
isMcNodeLocal bool
no setterinherited
isMcOrgLocal bool
no setterinherited
isMcSiteLocal bool
no setterinherited
isMulticastAddress bool
no setterinherited
isSiteLocalAddress bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isReachableWithNetworkTtlTimeout({NetworkInterface? netif, required int ttl, required int timetout}) bool
inherited
isReachableWithTimeout(int timeout) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited