Inet6AddressChannel class abstract base

Inheritance
  • Object
  • PlatformInterface
  • Inet6AddressChannel

Constructors

Inet6AddressChannel()
Constructs a Inet6AddressChannel.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() Inet6Address
createByAddressNetwork(String host, Uint8List addr, NetworkInterface nif) Inet6Address
createByAddressScopeId(String host, Uint8List addr, int scopeId) Inet6Address
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Inet6AddressChannel
The default instance of Inet6AddressChannel to use.
getter/setter pair