Locale$LanguageRangeChannel class abstract base

Inheritance
  • Object
  • PlatformInterface
  • Locale$LanguageRangeChannel

Properties

hashCode int
The hash code for this object.
no setterinherited
maxWeight double
no setter
minWeight double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(String range, [double? weight]) Locale$LanguageRange
mapEquivalents(List<Locale$LanguageRange> priorityList, Map<String, List<String>> map) List<Locale$LanguageRange>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String ranges, [Map<String, List<String>>? map]) List<Locale$LanguageRange>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Locale$LanguageRangeChannel
The default instance of Locale$LanguageRangeChannel to use.
getter/setter pair