Settings$NameValueTableChannel class abstract base

Inheritance
  • Object
  • PlatformInterface
  • Settings$NameValueTableChannel

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
no setter

Methods

create() Settings$NameValueTable
getUriFor(Uri uri, String name) Uri?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Settings$NameValueTableChannel
The default instance of Settings$NameValueTableChannel to use.
getter/setter pair