TimeZoneCapabilities class abstract interface

Properties

configureAutoDetectionEnabledCapability Capabilities
no setter
configureGeoDetectionEnabledCapability Capabilities
no setter
hashCode int
The hash code for this object.
no setterinherited
isUseLocationEnabled bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setManualTimeZoneCapability Capabilities
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited