UnixEpochTimeChannel class abstract base

Inheritance
  • Object
  • PlatformInterface
  • UnixEpochTimeChannel

Constructors

UnixEpochTimeChannel()
Constructs a UnixEpochTimeChannel.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required int elapsedRealtimeMillis, required int unixEpochTimeMillis}) UnixEpochTime
elapsedRealtimeDifference(UnixEpochTime one, UnixEpochTime two) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance UnixEpochTimeChannel
The default instance of UnixEpochTimeChannel to use.
getter/setter pair