Constructors
-
ConnectivityManager$NetworkCallback({bool includeLocationInfo = false, void onAvailable(Network network)?, void onBlockedStatusChanged(Network network, bool blocked)?, void onCapabilitiesChanged(Network network, NetworkCapabilities networkCapabilities)?, void onLinkPropertiesChanged(Network network, LinkProperties linkProperties)?, void onLosing(Network network, int maxMsToLive)?, void onLost(Network network)?, void onReserved(NetworkCapabilities networkCapabilities)?, void onUnavailable()?})
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited