Handle to a pre-located property. Looking up a property handle in advance allows for optimal repeated lookup of a single property.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
) → String - return Value of the property
-
getBoolean(
bool defaultValue) → bool - return value or defaultValue on parse error
-
getInt(
int defaultValue) → int - return value or defaultValue on parse error
-
getLong(
int defaultValue) → int - return value or defaultValue on parse error
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited